==> anwiba-spatial-data-gpsd-1.0.68-sources.jar: net/anwiba/spatial/gps/gpsd/response/Device.java <==
//// Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonProperty;

public class Device
    extends Response
{

    private final String _class = "DEVICE";
    private String path = null;
    private String activated = null;
    private int flags = 0;
    private String driver = null;
    private String subtype = null;
    private int bps = 0;
    private String parity = null;
    private String stopbits = null;
    private int _native = 0;
    private int cycle = 0;
    private int mincycle = 0;

    @JsonProperty("class")
    public void setClass(final String _class) {
    }

    @JsonProperty("class")
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("path")
    public void setPath(final String path) {
        this.path = path;
    }

    @JsonProperty("path")
    public String getPath() {
        return this.path;
    }

    @JsonProperty("activated")
    public void setActivated(final String activated) {
        this.activated = activated;
    }

    @JsonProperty("activated")
    public String getActivated() {
        return this.activated;
    }

    @JsonProperty("flags")
    public void setFlags(final int flags) {
        this.flags = flags;
    }

    @JsonProperty("flags")
    public int getFlags() {
        return this.flags;
    }

    @JsonProperty("driver")
    public void setDriver(final String driver) {
        this.driver = driver;
    }

    @JsonProperty("driver")
    public String getDriver() {
        return this.driver;
    }

    @JsonProperty("subtype")
    public void setSubtype(final String subtype) {
        this.subtype = subtype;
    }

    @JsonProperty("subtype")
    public String getSubtype() {
        return this.subtype;
    }

    @JsonProperty("bps")
    public void setBps(final int bps) {
        this.bps = bps;
    }

    @JsonProperty("bps")
    public int getBps() {
        return this.bps;
    }

    @JsonProperty("parity")
    public void setParity(final String parity) {
        this.parity = parity;
    }

    @JsonProperty("parity")
    public String getParity() {
        return this.parity;
    }

    @JsonProperty("stopbits")
    public void setStopbits(final String stopbits) {
        this.stopbits = stopbits;
    }

    @JsonProperty("stopbits")
    public String getStopbits() {
        return this.stopbits;
    }

    @JsonProperty("native")
    public void setNative(final int _native) {
        this._native = _native;
    }

    @JsonProperty("native")
    public int getNative() {
        return this._native;
    }

    @JsonProperty("cycle")
    public void setCycle(final int cycle) {
        this.cycle = cycle;
    }

    @JsonProperty("cycle")
    public int getCycle() {
        return this.cycle;
    }

    @JsonProperty("mincycle")
    public void setMincycle(final int mincycle) {
        this.mincycle = mincycle;
    }

    @JsonProperty("mincycle")
    public int getMincycle() {
        return this.mincycle;
    }

}

==> anwiba-spatial-data-gpsd-1.0.185-sources.jar: net/anwiba/spatial/gps/gpsd/response/Device.java <==
//// Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Device
    extends Response
{

    private final String _class = "DEVICE";
    private String path = null;
    private String activated = null;
    private int flags = 0;
    private String driver = null;
    private String subtype = null;
    private int bps = 0;
    private String parity = null;
    private String stopbits = null;
    private int _native = 0;
    private int cycle = 0;
    private int mincycle = 0;

    @JsonIgnore
    public void setClass(final String _class) {
    }

    @JsonIgnore
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("path")
    public void setPath(final String path) {
        this.path = path;
    }

    @JsonProperty("path")
    public String getPath() {
        return this.path;
    }

    @JsonProperty("activated")
    public void setActivated(final String activated) {
        this.activated = activated;
    }

    @JsonProperty("activated")
    public String getActivated() {
        return this.activated;
    }

    @JsonProperty("flags")
    public void setFlags(final int flags) {
        this.flags = flags;
    }

    @JsonProperty("flags")
    public int getFlags() {
        return this.flags;
    }

    @JsonProperty("driver")
    public void setDriver(final String driver) {
        this.driver = driver;
    }

    @JsonProperty("driver")
    public String getDriver() {
        return this.driver;
    }

    @JsonProperty("subtype")
    public void setSubtype(final String subtype) {
        this.subtype = subtype;
    }

    @JsonProperty("subtype")
    public String getSubtype() {
        return this.subtype;
    }

    @JsonProperty("bps")
    public void setBps(final int bps) {
        this.bps = bps;
    }

    @JsonProperty("bps")
    public int getBps() {
        return this.bps;
    }

    @JsonProperty("parity")
    public void setParity(final String parity) {
        this.parity = parity;
    }

    @JsonProperty("parity")
    public String getParity() {
        return this.parity;
    }

    @JsonProperty("stopbits")
    public void setStopbits(final String stopbits) {
        this.stopbits = stopbits;
    }

    @JsonProperty("stopbits")
    public String getStopbits() {
        return this.stopbits;
    }

    @JsonProperty("native")
    public void setNative(final int _native) {
        this._native = _native;
    }

    @JsonProperty("native")
    public int getNative() {
        return this._native;
    }

    @JsonProperty("cycle")
    public void setCycle(final int cycle) {
        this.cycle = cycle;
    }

    @JsonProperty("cycle")
    public int getCycle() {
        return this.cycle;
    }

    @JsonProperty("mincycle")
    public void setMincycle(final int mincycle) {
        this.mincycle = mincycle;
    }

    @JsonProperty("mincycle")
    public int getMincycle() {
        return this.mincycle;
    }

}
